@@ -7,7 +7,7 @@ use warnings;
 
 use base q(Exporter);
 
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 require XSLoader;
 XSLoader::load('Text::SpeedyFx', $VERSION);
@@ -18,7 +18,7 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -26,7 +26,7 @@ Text::SpeedyFx - tokenize/hash large amount of strings efficiently
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -176,8 +176,6 @@ See also the F<eg/benchmark.pl> script.
 
 For performance reasons, C<hash()> method returns a L<tied hash|perltie> which is an interface to
 L<nedtries|http://www.nedprod.com/programs/portable/nedtries/>.
-While this seems controversal as L<perltie> interface increases the overhead, the overall result
-is positive, since the I<feature vector> generation step overrides the slow interface (B<beware: magic!!!>).
 The interesting property of a L<trie data structure|https://en.wikipedia.org/wiki/Trie>
 is that the keys are "nearly sorted" (and the first key is guaranteed to be the lowest), so:
 
@@ -188,8 +186,9 @@ is that the keys are "nearly sorted" (and the first key is guaranteed to be the
     ($min) = $sfx->hash_min($data);
     # (albeit the later being 2x faster)
 
+The downside is the magic involved, the C<delete> breaking the key order, and the memory usage.
 The hardcoded limit is 524288 unique keys per result, which consumes ~25MB of RAM on a 64-bit architecture.
-Exceeding this will C<croak> with the message I<"too many unique tokens in a single data chunk"> (dynamic allocation not yet supported).
+Exceeding this will C<croak> with the message I<"too many unique tokens in a single data chunk">.
 The only way to raise this limit is by recompilation of the XS module:
 
     perl Makefile.PL DEFINE=-DMAX_TRIE_SIZE=2097152
@@ -225,7 +224,7 @@ Stanislaw Pusep <stas@sysd.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Stanislaw Pusep.
+This software is copyright (c) 2014 by Stanislaw Pusep.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
